Agogosml
========

This project includes the library for Agogosml. Please refer to the overall documentation:

-  `User Guide - Getting Started <../docs/USER_GUIDE.rst>`__
-  `Developer Guide <../docs/DEVELOPER_GUIDE.rst>`__